@@ -18,10 +18,6 @@
  */
 /*
  * $Log: dao.h,v $
- * Revision 1.3  1999/01/24 16:03:57  mueller
- * Applied Radek Doulik's ring buffer patch. Added some cleanups and
- * improved behavior in error case.
- *
  * Revision 1.2  1998/08/15 20:47:16  mueller
  * Added support for GenericMMC driver.
  *
@@ -33,7 +29,6 @@
 #include "Toc.h"
 #include "CdrDriver.h"
 
-int writeDiskAtOnce(const Toc *, CdrDriver *, int nofBuffers, int swap,
-		    int testMode, int remoteMode);
+int writeDiskAtOnce(const Toc *, CdrDriver *, int, int);
 
 #endif
