@@ -22,14 +22,6 @@
 
 #include "Sample.h"
 
-#ifdef min
-/* I stupidly named a member function 'min' which clashes with the macro 'min'
- * on some operating systems. The macro is simply undefined here since it is
- * not used in this package anyway.
- */
-#undef min
-#endif
-
 class Msf {
 private:
 
