@@ -17,7 +17,7 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-static char rcsid[] = "$Id: SubTrack.cc,v 1.4 1999/03/27 19:50:28 mueller Exp $";
+static char rcsid[] = "$Id: SubTrack.cc,v 1.2 1998/05/22 18:33:19 mueller Exp $";
 
 #include <config.h>
 
@@ -25,30 +25,29 @@ static char rcsid[] = "$Id: SubTrack.cc,v 1.4 1999/03/27 19:50:28 mueller Exp $"
 
 #include "SubTrack.h"
 
-SubTrack::SubTrack(Type t, unsigned long start, const TrackData &data) 
-  : TrackData(data)
+SubTrack::SubTrack(Type t, unsigned long start, const AudioData &data) 
+  : AudioData(data)
 {
   type_ = t;
   start_ = start;
-  next_ = pred_ = NULL;
+  next_ = NULL;
 }
 
-SubTrack::SubTrack(Type t, const TrackData &data) 
-  : TrackData(data)
+SubTrack::SubTrack(Type t, const AudioData &data) 
+  : AudioData(data)
 {
   type_ = t;
   start_ = 0;
-  next_ = pred_ = NULL;
+  next_ = NULL;
 }
 
-SubTrack::SubTrack(const SubTrack &obj) : TrackData(obj)
+SubTrack::SubTrack(const SubTrack &obj) : AudioData(obj)
 {
   type_ = obj.type_;
   start_ = obj.start_;
-  next_ = pred_ = NULL;
+  next_ = NULL;
 }
 
 SubTrack::~SubTrack()
 {
-  next_ = pred_ = NULL;
 }
